import react from 'react';

import MouseHandler from './mouse-handler';

import '../../theme/slippy.css';
import SingleTouchHandler from './single-touch-handler';
import DoubleTouchHandler from './double-touch-handler';
import { useSelector } from 'react-redux';
import { MapState } from '../../store/map';

export interface Point {
  x: number;
  y: number;
}

export interface Translation {
  translate: Point;
}

export interface Scale {
  scale: {
    center: Point;
    factor: number;
  };
}

const Slippy: react.FC<{}> = () => {
  //console.log(`--- Rendering viewport, props: ${JSON.stringify(props)} ---`);

  const viewport = useSelector(
    (state: { map: MapState }) => state.map.viewport
  );

  return (
    <div className='slippy'>
      <MouseHandler>
        <SingleTouchHandler>
          <DoubleTouchHandler>
            <div
              style={{
                position: 'fixed',
                width: viewport.width + 'px',
                height: viewport.height + 'px',
              }}
            />
          </DoubleTouchHandler>
        </SingleTouchHandler>
      </MouseHandler>
    </div>
  );
};

export default Slippy;
